==> example-data-center-9.3.3-sources.jar: org/opendaylight/yang/gen/v1/urn/example/data/center/rev180807/box/out/box/in/open/OutputBuilder.java <==
package org.opendaylight.yang.gen.v1.urn.example.data.center.rev180807.box.out.box.in.open;
import com.google.common.base.MoreObjects;
import com.google.common.collect.ImmutableMap;
import java.lang.Class;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.SuppressWarnings;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;
import org.opendaylight.yangtools.concepts.Builder;
import org.opendaylight.yangtools.yang.binding.Augmentation;
import org.opendaylight.yangtools.yang.binding.AugmentationHolder;
import org.opendaylight.yangtools.yang.binding.CodeHelpers;
import org.opendaylight.yangtools.yang.binding.DataObject;

/**
 * Class that builds {@link OutputBuilder} instances.
 *
 * @see OutputBuilder
 *
 */
public class OutputBuilder implements Builder<Output> {



    Map<Class<? extends Augmentation<Output>>, Augmentation<Output>> augmentation = Collections.emptyMap();

    public OutputBuilder() {
    }

    public OutputBuilder(Output base) {
        if (base instanceof OutputImpl) {
            OutputImpl impl = (OutputImpl) base;
            if (!impl.augmentation.isEmpty()) {
                this.augmentation = new HashMap<>(impl.augmentation);
            }
        } else if (base instanceof AugmentationHolder) {
            @SuppressWarnings("unchecked")
            Map<Class<? extends Augmentation<Output>>, Augmentation<Output>> aug =((AugmentationHolder<Output>) base).augmentations();
            if (!aug.isEmpty()) {
                this.augmentation = new HashMap<>(aug);
            }
        }
    }


    
    @SuppressWarnings({ "unchecked", "checkstyle:methodTypeParameterName"})
    public <E$$ extends Augmentation<Output>> E$$ augmentation(Class<E$$> augmentationType) {
        return (E$$) augmentation.get(CodeHelpers.nonNullValue(augmentationType, "augmentationType"));
    }

    
    public OutputBuilder addAugmentation(Class<? extends Augmentation<Output>> augmentationType, Augmentation<Output> augmentationValue) {
        if (augmentationValue == null) {
            return removeAugmentation(augmentationType);
        }
    
        if (!(this.augmentation instanceof HashMap)) {
            this.augmentation = new HashMap<>();
        }
    
        this.augmentation.put(augmentationType, augmentationValue);
        return this;
    }
    
    public OutputBuilder removeAugmentation(Class<? extends Augmentation<Output>> augmentationType) {
        if (this.augmentation instanceof HashMap) {
            this.augmentation.remove(augmentationType);
        }
        return this;
    }

    @Override
    public Output build() {
        return new OutputImpl(this);
    }

    private static final class OutputImpl implements Output {
    
    
        private Map<Class<? extends Augmentation<Output>>, Augmentation<Output>> augmentation = Collections.emptyMap();
    
        OutputImpl(OutputBuilder base) {
            this.augmentation = ImmutableMap.copyOf(base.augmentation);
        }
    
        @Override
        public Class<Output> getImplementedInterface() {
            return Output.class;
        }
    
        
        @SuppressWarnings({ "unchecked", "checkstyle:methodTypeParameterName"})
        @Override
        public <E$$ extends Augmentation<Output>> E$$ augmentation(Class<E$$> augmentationType) {
            return (E$$) augmentation.get(CodeHelpers.nonNullValue(augmentationType, "augmentationType"));
        }
    
        private int hash = 0;
        private volatile boolean hashValid = false;
        
        @Override
        public int hashCode() {
            if (hashValid) {
                return hash;
            }
        
            final int prime = 31;
            int result = 1;
            result = prime * result + Objects.hashCode(augmentation);
        
            hash = result;
            hashValid = true;
            return result;
        }
    
        @Override
        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (!(obj instanceof DataObject)) {
                return false;
            }
            if (!Output.class.equals(((DataObject)obj).getImplementedInterface())) {
                return false;
            }
            Output other = (Output)obj;
            if (getClass() == obj.getClass()) {
                // Simple case: we are comparing against self
                OutputImpl otherImpl = (OutputImpl) obj;
                if (!Objects.equals(augmentation, otherImpl.augmentation)) {
                    return false;
                }
            } else {
                // Hard case: compare our augments with presence there...
                for (Map.Entry<Class<? extends Augmentation<Output>>, Augmentation<Output>> e : augmentation.entrySet()) {
                    if (!e.getValue().equals(other.augmentation(e.getKey()))) {
                        return false;
                    }
                }
                // .. and give the other one the chance to do the same
                if (!obj.equals(this)) {
                    return false;
                }
            }
            return true;
        }
    
        @Override
        public String toString() {
            final MoreObjects.ToStringHelper helper = MoreObjects.toStringHelper("Output");
            CodeHelpers.appendValue(helper, "augmentation", augmentation.values());
            return helper.toString();
        }
    }
}

==> example-data-center-10.2.1-sources.jar: org/opendaylight/yang/gen/v1/urn/example/data/center/rev180807/box/out/box/in/open/OutputBuilder.java <==
package org.opendaylight.yang.gen.v1.urn.example.data.center.rev180807.box.out.box.in.open;
import com.google.common.base.MoreObjects;
import java.lang.Class;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.SuppressWarnings;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;
import org.opendaylight.yangtools.concepts.Builder;
import org.opendaylight.yangtools.yang.binding.AbstractAugmentable;
import org.opendaylight.yangtools.yang.binding.Augmentation;
import org.opendaylight.yangtools.yang.binding.AugmentationHolder;
import org.opendaylight.yangtools.yang.binding.CodeHelpers;
import org.opendaylight.yangtools.yang.binding.DataObject;

/**
 * Class that builds {@link OutputBuilder} instances.
 *
 * @see OutputBuilder
 *
 */
public class OutputBuilder implements Builder<Output> {



    Map<Class<? extends Augmentation<Output>>, Augmentation<Output>> augmentation = Collections.emptyMap();

    public OutputBuilder() {
    }

    public OutputBuilder(Output base) {
        if (base instanceof AugmentationHolder) {
            @SuppressWarnings("unchecked")
            Map<Class<? extends Augmentation<Output>>, Augmentation<Output>> aug =((AugmentationHolder<Output>) base).augmentations();
            if (!aug.isEmpty()) {
                this.augmentation = new HashMap<>(aug);
            }
        }
    }



    @SuppressWarnings({ "unchecked", "checkstyle:methodTypeParameterName"})
    public <E$$ extends Augmentation<Output>> E$$ augmentation(Class<E$$> augmentationType) {
        return (E$$) augmentation.get(CodeHelpers.nonNullValue(augmentationType, "augmentationType"));
    }

    
    public OutputBuilder addAugmentation(Class<? extends Augmentation<Output>> augmentationType, Augmentation<Output> augmentationValue) {
        if (augmentationValue == null) {
            return removeAugmentation(augmentationType);
        }
    
        if (!(this.augmentation instanceof HashMap)) {
            this.augmentation = new HashMap<>();
        }
    
        this.augmentation.put(augmentationType, augmentationValue);
        return this;
    }
    
    public OutputBuilder removeAugmentation(Class<? extends Augmentation<Output>> augmentationType) {
        if (this.augmentation instanceof HashMap) {
            this.augmentation.remove(augmentationType);
        }
        return this;
    }

    @Override
    public Output build() {
        return new OutputImpl(this);
    }

    private static final class OutputImpl
        extends AbstractAugmentable<Output>
        implements Output {
    
    
        OutputImpl(OutputBuilder base) {
            super(base.augmentation);
        }
    
        @Override
        public Class<Output> getImplementedInterface() {
            return Output.class;
        }
    
    
        private int hash = 0;
        private volatile boolean hashValid = false;
        
        @Override
        public int hashCode() {
            if (hashValid) {
                return hash;
            }
        
            final int prime = 31;
            int result = 1;
            result = prime * result + Objects.hashCode(augmentations());
        
            hash = result;
            hashValid = true;
            return result;
        }
    
        @Override
        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (!(obj instanceof DataObject)) {
                return false;
            }
            if (!Output.class.equals(((DataObject)obj).getImplementedInterface())) {
                return false;
            }
            Output other = (Output)obj;
            if (getClass() == obj.getClass()) {
                // Simple case: we are comparing against self
                OutputImpl otherImpl = (OutputImpl) obj;
                if (!Objects.equals(augmentations(), otherImpl.augmentations())) {
                    return false;
                }
            } else {
                // Hard case: compare our augments with presence there...
                for (Map.Entry<Class<? extends Augmentation<Output>>, Augmentation<Output>> e : augmentations().entrySet()) {
                    if (!e.getValue().equals(other.augmentation(e.getKey()))) {
                        return false;
                    }
                }
                // .. and give the other one the chance to do the same
                if (!obj.equals(this)) {
                    return false;
                }
            }
            return true;
        }
    
        @Override
        public String toString() {
            final MoreObjects.ToStringHelper helper = MoreObjects.toStringHelper("Output");
            CodeHelpers.appendValue(helper, "augmentation", augmentations().values());
            return helper.toString();
        }
    }
}
